@@ -9,7 +9,9 @@ def slugify(value):
     trailing whitespace.
     """
     value = (
-        unicodedata.normalize("NFKD", value).encode("ascii", "ignore").decode("ascii")
+        unicodedata.normalize("NFKD", value)
+        .encode("ascii", "ignore")
+        .decode("ascii")
     )
     value = re.sub(r"[^\w\s-]", "", value).strip().lower()
     return re.sub(r"[-\s]+", "-", value)
